Skip to contents

A data frame containing boolean (TRUE/FALSE) values indicating the objects/information available for each modelled taxon.

Usage

ModelObjectAvailability

Format

A data frame with 8897 rows and 8 columns, the definitions of which are:

taxon_code

The taxon, see elements::ModelledTaxaCodes.

imbalance

A boolean value indicating whether the taxon has data in elements::Imbalances.

nichewidth

A boolean value indicating whether the taxon has data in elements::NicheWidths.

performance

A boolean value indicating whether the taxon has data in elements::PerformanceMeasures.

ale

A boolean value indicating whether the taxon has data in elements::ALEData.

pdp

A boolean value indicating whether the taxon has data in elements::PDPData.

hoa

A boolean value indicating whether the taxon has data in elements::HOAData.

model

A boolean value indicating whether the taxon has a ecological niche model as present in ./inst/extdata/Models.

Details

ModelObjectAvailability