Skip to contents

Generate a plot containing the bivariate probability distribution of a taxon for two variables generated using the Hold-At-Optima (HOA) method present in elements::predict_occ.

Usage

plot_be(taxon, vars)

Arguments

taxon

A string containing a taxon name as present in elements::ModelledTaxaCodes.

vars

A vector of strings containing two variable names as present in elements::VariableNames

Value

A plot containing the bivariate probability distribution of a taxon for two variables.

Examples

elements::startup(); elements::plot_be(taxon = "carex_rostrata", vars = c("tmax_sm", "tmin_wt"))
#> elements startup completed.