A lookup between the taxon names, taxon codes and success of selected workflow steps
Source:R/data.R
ModellingTaxaLookup.RdA lookup between the taxon names, taxon codes and success of selected workflow steps in the model-fitting process.
Format
A data frame with 11228 rows and 8 columns, the definitions of which are:
- taxon_name
Taxon names.
- taxon_code
The taxon code, see
elements::TaxonomicBackbone- imbalance
A boolean (TRUE/FALSE) representing whether ... were successfully calculated, see
elements::Imbalances.- nichewidth
A boolean (TRUE/FALSE) representing whether ... were successfully calculated, see
elements::NicheWidths.- performance
A boolean (TRUE/FALSE) representing whether ... were successfully calculated, see
elements::PerformanceMeasures.- ale
A boolean (TRUE/FALSE) representing whether ... were successfully calculated, see
elements::ALEData.- pdp
A boolean (TRUE/FALSE) representing whether ... were successfully calculated, see
elements::PDPData.- model
A boolean (TRUE/FALSE) representing whether ... were successfully fitted.