Skip to contents

The taxon names and codes for taxa with more than 30 presences in the EVA, with the associated taxon concept information retireved from GBIF. For taxa which were successfully modelled see elements::ModellingTaxaLookup.

Usage

TaxonomicBackbone

Format

A data frame with 11612 rows and 11 columns, the definitions of which are:

taxon_name

Taxon names.

taxon_code

The taxon codes used throughout the package, formed from the taxon_name values by coercing all letters to lower and replacing whitespace with underscores.

scientificName

The full scientific name of the taxon, which includes the author. Retrieved from GBIF.

canonicalName

The full name of the taxon. Retrieved from GBIF.

rank

The rank of the taxon.

genus

The parent Genus taxon associated with the Species.

family

The parent Family taxon associated with the Species.

order

The parent Order taxon associated with the Species.

class

The parent Class taxon associated with the Species.

phylum

The parent Phylum taxon associated with the Species.

kingdom

The parent Kingdom taxon associated with the Species.

Details

TaxonomicBackbone