Generate a plot containing the bivariate probability distribution of a taxon for two variables
generated using the Hold-At-Optima (HOA) method present in elements::predict_occ.
Arguments
- taxon
A string containing a taxon name as present in
elements::ModelledTaxaCodes.- vars
A vector of strings containing two variable names as present in
elements::VariableNames
Examples
elements::startup(); elements::plot_be(taxon = "carex_rostrata", vars = c("tmax_sm", "tmin_wt"))
#> elements startup completed.
#> Error in elements::predict_occ(taxa = taxon, predictors = dat, holdopt = setdiff(elements::VariableNames, vars)): All model variables (L, M, N, R, S, SD, GP, tmax_sm, tmin_wt, prec_wt, prec_sm) must either be present in the predictors data frame or passed to holdopt.